function [ff,lab,f] = getfeature(b,show)
% Extract features from handwritten digit data.
%    [ff,lab,f] = getfeature(b,show)
%
%    Inputs:
%        b    ... digit data (a cell array)
%        show ... set to 1 to see a plot (default = 0)
%    Outputs:
%        ff   ... features returned in a matrix
%        lab  ... corresponding labels
%        f    ... features returned in the same structure as b (a cell array)
%
%    to see how the features look like, try:
%
%          load chars;
%          getfeature(b{1}{1},1);
%          getfeature(b{2}{1},1);
%          etc.
%    

if nargin < 2, show = 0; end;
if ~iscell(b), bb{1}{1} = b; b = bb; clear bb; end; 

da = 15*pi/180;
angles = [0:30:360-30]'*pi/180;
center = [0 -200;0 200];
%center = [0 0];

kk = 0;
for ii = 1 : length(b),
   for jj = 1 : length(b{ii}),
      
        a = b{ii}{jj};
		a = (centralize(a));
        r = max(max(a)-min(a));
        [x,y] = pol2cart(angles,r);
                
        if show, plot(a(:,1),a(:,2),'.','linewidth',4,'markersize',30); hold on; end;
        for j = 1 : size(center,1),
        for i = 1 : length(angles),
            xy = inter_curve([center(j,1)+[0;x(i)] center(j,2)+[0;y(i)]],a);
            if ~isempty(xy),
                [rr,ind] = sort(diag(sqrt((xy-ones(size(xy,1),1)*center(j,:))*(xy-ones(size(xy,1),1)*center(j,:))')));
                xy = xy(ind,:);
		        F(i,j) = rr(1); 
                
		    else
		        F(i,j) = 0;
		    end;    
            if show & F(i,j)>0, 
                plot([center(j,1);xy(1,1)],[center(j,2);xy(1,2)],'r','linewidth',1);
% 		         h = polar([angles(i) angles(i)],[center(j,:)  r/2],'g'); set(h,'linewidth',2);
%                h = polar([angles(i) angles(i)],[0 F(i,2)],'k'); set(h,'linewidth',2);
%                h = polar([angles(i) angles(i)],[center(j,:) F(i,1)],'r'); set(h,'linewidth',2);
            end;    
		end;
    end;
        F = F/1000;
        kk = kk + 1;
        ff(:,kk) = F(:);
        lab(kk) = ii;
        f{ii}{jj} = F(:);
		if show, hold off; end;
   end;
end;
