% Handwritten digit recognition by using neural networks

load chars                                          % load character data set

dig = [1 2 3 4 5 6 7 8 9 10]';                      % digits (10 stands for 0)
[P,lab] = getfeature4(b);                            % extract features (patterns)
T = ones(size(dig))*lab == dig*ones(1,size(P,2));   % construct targets

N = 3;                                              % use 1/N of the data for testing
[trash,ind] = sort(rand(size(P,2),1));              % random indices
Ptest = P(:,ind(1:end/N));                          % test data
Ttest = T(:,ind(1:end/N));
labtest = lab(ind(1:end/N));
P = P(:,ind(end/N+1:end));                          % training data
T = T(:,ind(end/N+1:end));


S1 = 25;                                            % # of hidden-layer neurons
S2 = length(dig);                                   % # of output-layer neurons
net = newff(minmax(P),[S1 S2],{'logsig' 'logsig'},'traingdx'); % new feedforward net 
net.LW{2,1} = net.LW{2,1}*0.1;                      % smaller initial weights
net.b{2} = net.b{2}*0.1;                            % smaller initial weights

net.performFcn = 'sse';                             % Sum-Squared Error performance function
net.trainParam.goal = 1e-6;                         % Sum-squared error goal
%net.trainparam.min_grad = 1e-100;
net.trainParam.show = 50;                           % Frequency of progress displays (in epochs)
net.trainParam.epochs = 1000;                       % Maximum number of epochs to train
net.trainParam.mc = 0.9;                            % Momentum constant.

[net,tr] = train(net,P,T);                          % train the network

A = sim(net,Ptest);                                 % compute output of the net
[trash,ind]=max(A);
100*sum(dig(ind) == labtest')/length(labtest)       % percent correct

